Actions, Resources, and Condition Keys for AWS CodePipeline - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodePipeline.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for AWS CodePipeline

AWS CodePipeline (service prefix: `codepipeline`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS CodePipeline
- Resources Defined by AWS CodePipeline
- Condition Keys for AWS CodePipeline

## Actions Defined by AWS CodePipeline

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AcknowledgeJob | Returns information about a specified job and whether that job has been received by the job worker. | Write |  |  |
AcknowledgeThirdPartyJob | Confirms a job worker has received the specified job. Only used for partner actions. | Write |  |  |
CreateCustomActionType | Create a custom action you can use in the pipelines associated with your AWS account. | Tagging | actiontype* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreatePipeline | Create a uniquely named pipeline. | Tagging | pipeline* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteCustomActionType | Delete a custom action. | Write | actiontype* |  |
DeletePipeline | Delete a specified pipeline. | Write | pipeline* |  |
DeleteWebhook | Delete a specified webhook. | Write | webhook* |  |
DeregisterWebhookWithThirdParty | Remove the registration of a webhook with the third party specified in its configuration. | Write | webhook* |  |
DisableStageTransition | Prevent revisions from transitioning to the next stage in a pipeline. | Write | stage* |  |
EnableStageTransition | Enable revisions to transition to the next stage in a pipeline. | Write | stage* |  |
GetJobDetails | Returns information about a job | Read |  |  |
GetPipeline | Retrieve information about a pipeline structure. | Read | pipeline* |  |
GetPipelineExecution | Returns information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline | Read | pipeline* |  |
GetPipelineState | Retrieve information about the current state of the stages and actions of a pipeline. | Read | pipeline* |  |
GetThirdPartyJobDetails | Requests the details of a job for a third party action. Only used for partner actions. | Read |  |  |
ListActionExecutions | Returns a list of the most recent action executions that has happened in a pipeline. | Read | pipeline* |  |
ListActionTypes | Retrieve a summary of all the action types available for pipelines in your account. | Read | actiontype* |  |
ListPipelineExecutions | Gets a summary of the most recent executions for a pipeline. | List | pipeline* |  |
ListPipelines | Get a summary of all the pipelines associated with your AWS account. | List | pipeline* |  |
ListTagsForResource | Lists tags for a CodePipeline resource. | Read | actiontype |  |
pipeline |  |
webhook |  |
ListWebhooks | Get all the webhooks associated with your AWS account. | List | webhook* |  |
PollForJobs | Returns information about any jobs for AWS CodePipeline to act upon. | Write | actiontype* |  |
PollForThirdPartyJobs | Determines whether there are any third party jobs for a job worker to act on. Only used for partner actions. | Write |  |  |
PutActionRevision | Edit actions within a pipeline. | Write | action* |  |
PutApprovalResult | Provides the response to a manual approval request to AWS CodePipeline. Valid responses include Approved and Rejected. | Write | action* |  |
PutJobFailureResult | Represents the failure of a job as returned to the pipeline by a job worker. Only used for custom actions. | Write |  |  |
PutJobSuccessResult | Represents the success of a job as returned to the pipeline by a job worker. Only used for custom actions. | Write |  |  |
PutThirdPartyJobFailureResult | Represents the failure of a third party job as returned to the pipeline by a job worker. Only used for partner actions. | Write |  |  |
PutThirdPartyJobSuccessResult | Represents the success of a third party job as returned to the pipeline by a job worker. Only used for partner actions. | Write |  |  |
PutWebhook | Create or update a webhook | Tagging | pipeline* |  |
webhook* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
RegisterWebhookWithThirdParty | Register a webhook with the third party specified in its configuration. | Write | webhook* |  |
RetryStageExecution | Resumes the pipeline execution by retrying the last failed actions in a stage | Write | stage* |  |
StartPipelineExecution | Run the most recent revision through the pipeline. | Write | pipeline* |  |
TagResource | Tags a CodePipeline resource. | Tagging | actiontype |  |
pipeline |  |
webhook |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Removes a tag from a CodePipeline resource. | Tagging | actiontype |  |
pipeline |  |
webhook |  |
| aws:TagKeys |
UpdatePipeline | Update a pipeline with changes to the structure of the pipeline. | Write | pipeline* |  |

## Resources Defined by AWS CodePipeline

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
action | `arn:${Partition}:codepipeline:${Region}:${Account}:${PipelineName}/${StageName}/${ActionName}` | aws:ResourceTag/${TagKey}
actiontype | `arn:${Partition}:codepipeline:${Region}:${Account}:actiontype:${Owner}/${Category}/${Provider}/${Version}` | aws:ResourceTag/${TagKey}
pipeline | `arn:${Partition}:codepipeline:${Region}:${Account}:${PipelineName}` | aws:ResourceTag/${TagKey}
stage | `arn:${Partition}:codepipeline:${Region}:${Account}:${PipelineName}/${StageName}` | aws:ResourceTag/${TagKey}
webhook | `arn:${Partition}:codepipeline:${Region}:${Account}:webhook:${WebhookName}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS CodePipeline

AWS CodePipeline defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

On this page:

- Actions Defined by AWS CodePipeline
- Resources Defined by AWS CodePipeline
- Condition Keys for AWS CodePipeline

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more